@@ -21,7 +21,7 @@ from .literals import EndpointAccessTypeType
 from .paginator import ListEndpointsPaginator
 from .type_defs import CreateEndpointResultTypeDef, ListEndpointsResultTypeDef
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -49,7 +49,7 @@ class Exceptions:
 
 class S3OutpostsClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html)
     """
 
@@ -65,7 +65,7 @@ class S3OutpostsClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#can_paginate)
         """
 
@@ -75,14 +75,14 @@ class S3OutpostsClient(BaseClient):
         OutpostId: str,
         SubnetId: str,
         SecurityGroupId: str,
-        AccessType: EndpointAccessTypeType = None,
-        CustomerOwnedIpv4Pool: str = None
+        AccessType: EndpointAccessTypeType = ...,
+        CustomerOwnedIpv4Pool: str = ...
     ) -> CreateEndpointResultTypeDef:
         """
         Amazon S3 on Outposts Access Points simplify managing data access at scale for
         shared datasets in S3 on Outposts.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Client.create_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Client.create_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#create_endpoint)
         """
 
@@ -91,37 +91,37 @@ class S3OutpostsClient(BaseClient):
         Amazon S3 on Outposts Access Points simplify managing data access at scale for
         shared datasets in S3 on Outposts.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Client.delete_endpoint)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Client.delete_endpoint)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#delete_endpoint)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#generate_presigned_url)
         """
 
     def list_endpoints(
-        self, *, NextToken: str = None, MaxResults: int = None
+        self, *, NextToken: str = ..., MaxResults: int = ...
     ) -> ListEndpointsResultTypeDef:
         """
         Amazon S3 on Outposts Access Points simplify managing data access at scale for
         shared datasets in S3 on Outposts.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Client.list_endpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Client.list_endpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/client.html#list_endpoints)
         """
 
     def get_paginator(self, operation_name: Literal["list_endpoints"]) -> ListEndpointsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.46/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.19.2/reference/services/s3outposts.html#S3Outposts.Paginator.ListEndpoints)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_s3outposts/paginators.html#listendpointspaginator)
         """
